@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.80_01';
+our $VERSION   = '0.82_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -58,8 +58,8 @@ sub accessor_type        { (shift)->{'accessor_type'} }
 ## factory
 
 sub initialize_body {
-    warn 'The initialize_body method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The initialize_body method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_initialize_body;
 }
 
@@ -80,8 +80,8 @@ sub _initialize_body {
 ## generators
 
 sub generate_accessor_method {
-    warn 'The generate_accessor_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_accessor_method method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_accessor_method;
 }
 
@@ -94,8 +94,8 @@ sub _generate_accessor_method {
 }
 
 sub generate_reader_method {
-    warn 'The generate_reader_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_reader_method method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_reader_method;
 }
 
@@ -108,8 +108,8 @@ sub _generate_reader_method {
 }
 
 sub generate_writer_method {
-    warn 'The generate_writer_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_writer_method method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_writer_method;
 }
 
@@ -121,8 +121,8 @@ sub _generate_writer_method {
 }
 
 sub generate_predicate_method {
-    warn 'The generate_predicate_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_predicate_method method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_predicate_method;
 }
 
@@ -134,8 +134,8 @@ sub _generate_predicate_method {
 }
 
 sub generate_clearer_method {
-    warn 'The generate_clearer_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_clearer_method method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_clearer_method;
 }
 
@@ -149,8 +149,8 @@ sub _generate_clearer_method {
 ## Inline methods
 
 sub generate_accessor_method_inline {
-    warn 'The generate_accessor_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_accessor_method_inline method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_accessor_method_inline;
 }
 
@@ -174,8 +174,8 @@ sub _generate_accessor_method_inline {
 }
 
 sub generate_reader_method_inline {
-    warn 'The generate_reader_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_reader_method_inline method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_reader_method_inline;
 }
 
@@ -198,8 +198,8 @@ sub _generate_reader_method_inline {
 }
 
 sub generate_writer_method_inline {
-    warn 'The generate_writer_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_writer_method_inline method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_writer_method_inline;
 }
 
@@ -221,8 +221,8 @@ sub _generate_writer_method_inline {
 }
 
 sub generate_predicate_method_inline {
-    warn 'The generate_predicate_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_predicate_method_inline method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_predicate_method_inline;
 }
 
@@ -244,8 +244,8 @@ sub _generate_predicate_method_inline {
 }
 
 sub generate_clearer_method_inline {
-    warn 'The generate_clearer_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_clearer_method_inline method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_clearer_method_inline;
 }
 
