@@ -7,11 +7,11 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken', 'looks_like_number';
 
-our $VERSION   = '0.80_01';
+our $VERSION   = '0.82_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
-use base 'Class::MOP::Method::Generated';
+use base 'Class::MOP::Method::Inlined';
 
 sub new {
     my $class   = shift;
@@ -52,8 +52,6 @@ sub _new {
     }, $class;
 }
 
-sub can_be_inlined { 1 }
-
 ## accessors
 
 sub options              { (shift)->{'options'}              }
@@ -62,8 +60,8 @@ sub associated_metaclass { (shift)->{'associated_metaclass'} }
 ## cached values ...
 
 sub meta_instance {
-    warn 'The meta_instance method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The meta_instance method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_meta_instance;
 }
 
@@ -73,8 +71,8 @@ sub _meta_instance {
 }
 
 sub attributes {
-    warn 'The attributes method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The attributes method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
 
     return shift->_attributes;
 }
@@ -87,8 +85,8 @@ sub _attributes {
 ## method
 
 sub initialize_body {
-    warn 'The initialize_body method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The initialize_body method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_initialize_body;
 }
 
@@ -102,8 +100,8 @@ sub _initialize_body {
 }
 
 sub generate_constructor_method {
-    warn 'The generate_constructor_method method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_constructor_method method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_constructor_method;
 }
 
@@ -112,8 +110,8 @@ sub _generate_constructor_method {
 }
 
 sub generate_constructor_method_inline {
-    warn 'The generate_constructor_method_inline method has been made private.'
-        . " The public version is deprecated and will be removed in a future release.\n";
+    Carp::cluck('The generate_constructor_method_inline method has been made private.'
+        . " The public version is deprecated and will be removed in a future release.\n");
     shift->_generate_constructor_method_inline;
 }
 
@@ -268,12 +266,6 @@ inlined.
 
 This returns the L<Class::MOP::Class> object for the method.
 
-=item B<< $metamethod->can_be_inlined >>
-
-This method always returns true in this class. It exists so that
-subclasses (as in Moose) can do some sort of checking to determine
-whether or not inlining the constructor is safe.
-
 =back
 
 =head1 AUTHORS
